@@ -5,15 +5,15 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.092 ;
+use IO::Compress::Base 2.093 ;
 
-use IO::Compress::Base::Common  2.092 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzf  2.092 ;
+use IO::Compress::Base::Common  2.093 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzf  2.093 ;
 #use Compress::Lzf ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzfError);
 
-$VERSION = '2.092';
+$VERSION = '2.093';
 $LzfError = '';
 
 @ISA    = qw( IO::Compress::Base Exporter );
@@ -200,7 +200,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
