@@ -4,16 +4,16 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.092 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.093 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.092 ;
-use IO::Uncompress::Adapter::Lzf  2.092 ;
+use IO::Uncompress::Base  2.093 ;
+use IO::Uncompress::Adapter::Lzf  2.093 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzfError);
 
-$VERSION = '2.092';
+$VERSION = '2.093';
 $UnLzfError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
@@ -310,7 +310,7 @@ It can take one of the following forms:
 
 =item A filename
 
-If the <$input_filename_or_reference> parameter is a simple scalar, it is
+If the C<$input_filename_or_reference> parameter is a simple scalar, it is
 assumed to be a filename. This file will be opened for reading and the
 input data will be read from it.
 
